.. image:: https://badge.fury.io/py/bitcoinX.svg
    :target: http://badge.fury.io/py/bitcoinX
.. image:: https://travis-ci.org/kyuupichan/bitcoinX.svg?branch=master
    :target: https://travis-ci.org/kyuupichan/bitcoinX
.. image:: https://coveralls.io/repos/github/kyuupichan/bitcoinX/badge.svg
    :target: https://coveralls.io/github/kyuupichan/bitcoinX

========
bitcoinX
========

A Python Bitcoin library that will grow to encompass network protocol,
consensus, transactions, scripting and signing.

  :Licence: MIT
  :Language: Python (>= 3.6)
  :Author: Neil Booth


Documentation
=============

In time.
